@@ -18,10 +18,6 @@
 #ifndef _BOINC_API_
 #define _BOINC_API_
 
-#ifdef __APPLE__
-#include <Carbon/Carbon.h>
-#endif
-
 #ifdef _WIN32
 #include "boinc_win.h"
 #endif
@@ -71,7 +67,6 @@ typedef struct BOINC_OPTIONS {
 typedef struct BOINC_STATUS {
     int no_heartbeat;
     int suspended;
-    int suspend_request;
     int quit_request;
     int reread_init_data_file;
     int abort_request;
@@ -88,7 +83,7 @@ struct APP_INIT_DATA;
 
 extern int boinc_init(void);
 extern int boinc_finish(int status);
-extern int boinc_temporary_exit(int delay);
+extern int boinc_temporary_exit(int delay, const char* reason=NULL);
 extern int boinc_get_init_data_p(struct APP_INIT_DATA*);
 extern int boinc_parse_init_data_file(void);
 extern int boinc_send_trickle_up(char* variety, char* text);
