@@ -240,14 +240,20 @@ void CLIENT_STATE::parse_cmdline(int argc, char** argv) {
             if (i == argc-1) show_options = true;
             else safe_strcpy(update_prefs_url, argv[++i]);
         } else if (ARG(version)) {
-#if (defined (__APPLE__) && (defined(__i386__) || defined(__x86_64__)))
+#ifdef __APPLE__
             CLIENT_STATE cs;
             cs.detect_platforms();
-            printf(BOINC_VERSION_STRING " %s\n", HOSTTYPE);
+            printf(BOINC_VERSION_STRING " %s\n", cs.get_primary_platform());
 #else
             printf(BOINC_VERSION_STRING " " HOSTTYPE "\n");
 #endif
             exit(0);
+#ifdef __APPLE__
+        // workaround for bug in XCode 4.2: accept but ignore 
+        // argument -NSDocumentRevisionsDebugMode=YES 
+        } else if (ARG(NSDocumentRevisionsDebugMode)) {
+            ++i; 
+#endif
         } else {
             printf("Unknown option: %s\n", argv[i]);
             show_options = true;
