@@ -440,7 +440,9 @@ bool CLIENT_STATE::scheduler_rpc_poll() {
 
     // report overdue results
     //
-    p = find_project_with_overdue_results();
+    bool suspend_soon = global_prefs.net_times.suspended(now + 1800);
+    suspend_soon |= global_prefs.cpu_times.suspended(now + 1800);
+    p = find_project_with_overdue_results(suspend_soon);
     if (p && !actively_uploading(p)) {
         work_fetch.compute_work_request(p);
         scheduler_op->init_op_project(p, RPC_REASON_RESULTS_DUE);
@@ -460,11 +462,13 @@ bool CLIENT_STATE::scheduler_rpc_poll() {
     must_check_work_fetch = false;
     last_work_fetch_time = now;
 
-    p = work_fetch.choose_project();
+    p = work_fetch.choose_project(true);
     if (p) {
         if (actively_uploading(p)) {
             if (log_flags.work_fetch_debug) {
-                msg_printf(p, MSG_INFO, "[work_fetch] deferring work fetch; upload active");
+                msg_printf(p, MSG_INFO,
+                    "[work_fetch] deferring work fetch; upload active"
+                );
             }
             return false;
         }
@@ -483,7 +487,9 @@ static inline bool requested_work() {
 
 // Handle the reply from a scheduler
 //
-int CLIENT_STATE::handle_scheduler_reply(PROJECT* project, char* scheduler_url) {
+int CLIENT_STATE::handle_scheduler_reply(
+    PROJECT* project, char* scheduler_url
+) {
     SCHEDULER_REPLY sr;
     FILE* f;
     int retval;
@@ -962,6 +968,7 @@ int CLIENT_STATE::handle_scheduler_reply(PROJECT* project, char* scheduler_url)
     if (sr.send_full_workload) {
         project->send_full_workload = true;
     }
+    project->dont_use_dcf = sr.dont_use_dcf;
     project->send_time_stats_log = sr.send_time_stats_log;
     project->send_job_log = sr.send_job_log;
     project->trickle_up_pending = false;
@@ -1165,13 +1172,17 @@ PROJECT* CLIENT_STATE::next_project_trickle_up_pending() {
 // find a project with finished results that should be reported.
 // This means:
 //    - we're not backing off contacting the project
+//    - no upload for that project is active
 //    - the result is ready_to_report (compute done; files uploaded)
 //    - we're within a day of the report deadline,
 //      or at least a day has elapsed since the result was completed,
 //      or we have a sporadic connection
 //      or the project is in "don't request more work" state
+//      or a network suspend period is coming up soon
 //
-PROJECT* CLIENT_STATE::find_project_with_overdue_results() {
+PROJECT* CLIENT_STATE::find_project_with_overdue_results(
+    bool network_suspend_soon
+) {
     unsigned int i;
     RESULT* r;
 
@@ -1182,6 +1193,7 @@ PROJECT* CLIENT_STATE::find_project_with_overdue_results() {
         PROJECT* p = r->project;
         if (p->waiting_until_min_rpc_time()) continue;
         if (p->suspended_via_gui) continue;
+        if (actively_uploading(p)) continue;
 
         if (p->dont_request_more_work) {
             return p;
@@ -1199,6 +1211,10 @@ PROJECT* CLIENT_STATE::find_project_with_overdue_results() {
             return p;
         }
 
+        if (network_suspend_soon) {
+            return p;
+        }
+
         double cushion = std::max(REPORT_DEADLINE_CUSHION, work_buf_min());
         if (gstate.now > r->report_deadline - cushion) {
             return p;
