@@ -62,9 +62,15 @@
 #endif
 
 #include <sys/stat.h>
+
 #if HAVE_SYS_SWAP_H
+#ifdef ANDROID
+#include <linux/swap.h>
+#else
 #include <sys/swap.h>
 #endif
+#endif
+
 #if HAVE_SYS_SYSCTL_H
 #include <sys/sysctl.h>
 #endif
@@ -422,7 +428,7 @@ static void parse_cpuinfo_linux(HOST_INFO& host) {
     strcpy(features, "");
     while (fgets(buf, 1024, f)) {
         strip_whitespace(buf);
-         if (
+        if (
                 /* there might be conflicts if we dont #ifdef */
 #ifdef __ia64__
             strstr(buf, "vendor     : ")
@@ -442,46 +448,48 @@ static void parse_cpuinfo_linux(HOST_INFO& host) {
                 vendor_found = true;
                 strlcpy(host.p_vendor, strchr(buf, ':') + 2, sizeof(host.p_vendor));
             } else if (!vendor_found) {
-            vendor_found = true;
-        strlcpy(buf2, strchr(buf, ':') + 2, sizeof(host.p_vendor) - strlen(host.p_vendor) - 1);
-        strcat(host.p_vendor, buf2);
+                vendor_found = true;
+                strlcpy(buf2, strchr(buf, ':') + 2,
+                    sizeof(host.p_vendor) - strlen(host.p_vendor) - 1
+                );
+                strlcat(host.p_vendor, buf2, sizeof(host.p_vendor));
             }
         }
         if (
 #ifdef __ia64__
-        strstr(buf, "family     : ") || strstr(buf, "model name : ")
+            strstr(buf, "family     : ") || strstr(buf, "model name : ")
 #elif __powerpc__ || __sparc__
-        strstr(buf, "cpu\t\t: ")
+            strstr(buf, "cpu\t\t: ")
 #else
-        strstr(buf, "model name\t: ") || strstr(buf, "cpu model\t\t: ")
+            strstr(buf, "model name\t: ") || strstr(buf, "cpu model\t\t: ")
 #endif
-                ) {
+        ) {
             if (!model_hack && !model_found) {
                 model_found = true;
 #ifdef __powerpc__
-        char *coma = NULL;
-            if ((coma = strrchr(buf, ','))) {   /* we have ", altivec supported" */
-            *coma = '\0';    /* strip the unwanted line */
-                strcpy(features, "altivec");
-                features_found = true;
-            }
+                char *coma = NULL;
+                if ((coma = strrchr(buf, ','))) {   /* we have ", altivec supported" */
+                    *coma = '\0';    /* strip the unwanted line */
+                    strcpy(features, "altivec");
+                    features_found = true;
+                }
 #endif
                 strlcpy(host.p_model, strchr(buf, ':') + 2, sizeof(host.p_model));
             } else if (!model_found) {
 #ifdef __ia64__
-        /* depending on kernel version, family can be either
-        a number or a string. If number, we have a model name,
-        else we don't */
-        char *testc = NULL;
-        testc = strrchr(buf, ':')+2;
-        if (isdigit(*testc)) {
-            family = atoi(testc);
-            continue;    /* skip this line */
-        }
+                /* depending on kernel version, family can be either
+                a number or a string. If number, we have a model name,
+                else we don't */
+                char *testc = NULL;
+                testc = strrchr(buf, ':')+2;
+                if (isdigit(*testc)) {
+                    family = atoi(testc);
+                    continue;    /* skip this line */
+                }
 #endif
-        model_found = true;
-        strlcpy(buf2, strchr(buf, ':') + 2, sizeof(host.p_model) - strlen(host.p_model) - 1);
-        strcat(host.p_model, buf2);
+                model_found = true;
+                strlcpy(buf2, strchr(buf, ':') + 2, sizeof(host.p_model) - strlen(host.p_model) - 1);
+                strcat(host.p_model, buf2);
             }
         }
 #ifndef __hppa__
@@ -536,7 +544,7 @@ static void parse_cpuinfo_linux(HOST_INFO& host) {
             } else if ((strstr(buf, "features\t\t: ") == buf)) {
                 strlcpy(features, strchr(buf, ':') + 2, sizeof(features));
             } else if ((strstr(buf, "features   : ") == buf)) {    /* ia64 */
-            strlcpy(features, strchr(buf, ':') + 2, sizeof(features));
+                strlcpy(features, strchr(buf, ':') + 2, sizeof(features));
             }
             if (strlen(features)) {
                 features_found = true;
@@ -607,7 +615,11 @@ void use_cpuid(HOST_INFO& host) {
     if (has3DNowExt) strncat(capabilities, "3dnowext ", 9);
     if (hasMMX) strncat(capabilities, "mmx ", 4);
     strip_whitespace(capabilities);
-    snprintf(host.p_model, sizeof(host.p_model), "%s [] [%s]", host.p_model, capabilities);
+    char buf[1024];
+    snprintf(buf, sizeof(buf), "%s [] [%s]",
+        host.p_model, capabilities
+    );
+    strlcat(host.p_model, buf, sizeof(host.p_model));
 }
 #endif
 #endif
@@ -827,7 +839,9 @@ static void get_cpu_info_haiku(HOST_INFO& host) {
 
 // detect the network usage totals for the host.
 //
-int get_network_usage_totals(unsigned int& total_received, unsigned int& total_sent) {
+int get_network_usage_totals(
+    unsigned int& total_received, unsigned int& total_sent
+) {
     static size_t  sysctlBufferSize = 0;
     static uint8_t *sysctlBuffer = NULL;
 
@@ -937,8 +951,7 @@ typedef struct {
 
 static io_connect_t conn;
 
-kern_return_t SMCOpen()
-{
+kern_return_t SMCOpen() {
     kern_return_t       result;
     mach_port_t         masterPort;
     io_iterator_t       iterator;
@@ -948,30 +961,26 @@ kern_return_t SMCOpen()
 
     CFMutableDictionaryRef matchingDictionary = IOServiceMatching("AppleSMC");
     result = IOServiceGetMatchingServices(masterPort, matchingDictionary, &iterator);
-    if (result != kIOReturnSuccess)
-    {
+    if (result != kIOReturnSuccess) {
         return result;
     }
 
     device = IOIteratorNext(iterator);
     IOObjectRelease(iterator);
-    if (device == 0)
-    {
+    if (device == 0) {
         return result;
     }
 
     result = IOServiceOpen(device, mach_task_self(), 0, &conn);
     IOObjectRelease(device);
-    if (result != kIOReturnSuccess)
-    {
+    if (result != kIOReturnSuccess) {
         return result;
     }
 
     return kIOReturnSuccess;
 }
 
-kern_return_t SMCClose()
-{
+kern_return_t SMCClose() {
     if (conn) {
         return IOServiceClose(conn);
     }
@@ -993,20 +1002,20 @@ kern_return_t SMCReadKey(UInt32 key, SMCBytes_t val) {
 
 #if MAC_OS_X_VERSION_MIN_REQUIRED >= MAC_OS_X_VERSION_10_5
     result = IOConnectCallStructMethod(conn,
-                                       KERNEL_INDEX_SMC,
-                                       &inputStructure,
-                                       sizeof(inputStructure),
-                                       &outputStructure,
-                                       &structureOutputSize
-                                       );
+        KERNEL_INDEX_SMC,
+        &inputStructure,
+        sizeof(inputStructure),
+        &outputStructure,
+        &structureOutputSize
+    );
 #else
     result = IOConnectMethodStructureIStructureO(conn,
-                                                 KERNEL_INDEX_SMC,
-                                                 sizeof(inputStructure),
-                                                 &structureOutputSize,
-                                                 &inputStructure,
-                                                 &outputStructure
-                                                 );
+        KERNEL_INDEX_SMC,
+        sizeof(inputStructure),
+        &structureOutputSize,
+        &inputStructure,
+        &outputStructure
+    );
 #endif
     if (result != kIOReturnSuccess) {
         return result;
@@ -1017,20 +1026,20 @@ kern_return_t SMCReadKey(UInt32 key, SMCBytes_t val) {
 
 #if MAC_OS_X_VERSION_MIN_REQUIRED >= MAC_OS_X_VERSION_10_5
     result = IOConnectCallStructMethod(conn,
-                                       KERNEL_INDEX_SMC,
-                                       &inputStructure,
-                                       sizeof(inputStructure),
-                                       &outputStructure,
-                                       &structureOutputSize
-                                       );
+        KERNEL_INDEX_SMC,
+        &inputStructure,
+        sizeof(inputStructure),
+        &outputStructure,
+        &structureOutputSize
+    );
 #else
     result = IOConnectMethodStructureIStructureO(conn,
-                                                 KERNEL_INDEX_SMC,
-                                                 sizeof(inputStructure),
-                                                 &structureOutputSize,
-                                                 &inputStructure,
-                                                 &outputStructure
-                                                 );
+        KERNEL_INDEX_SMC,
+        sizeof(inputStructure),
+        &structureOutputSize,
+        &inputStructure,
+        &outputStructure
+    );
 #endif
     if (result != kIOReturnSuccess) {
         return result;
@@ -1119,9 +1128,9 @@ int HOST_INFO::get_virtualbox_version() {
     OSStatus status = noErr;
 
     // First try to locate the VirtualBox application by Bundle ID and Creator Code
-    status = LSFindApplicationForInfo('VBOX', CFSTR("org.virtualbox.app.VirtualBox"),   
-                                        NULL, &theFSRef, NULL
-                                    );
+    status = LSFindApplicationForInfo(
+        'VBOX', CFSTR("org.virtualbox.app.VirtualBox"), NULL, &theFSRef, NULL
+    );
     if (status == noErr) {
         status = FSRefMakePath(&theFSRef, (unsigned char *)path, sizeof(path));
     }
@@ -1589,15 +1598,14 @@ inline bool user_idle(time_t t, struct utmp* u) {
 // CGEventSourceSecondsSinceLastEventType() API does work with ARD and VNC, 
 // except when BOINC is a pre-login launchd daemon running as user boinc_master.
 //
-// So as a workaround in OS 10.7, we use CGEventSourceSecondsSinceLastEventType 
-// unless running as a daemon.  Therefore BOINC still won't detect activity from
-// remote via Apple Remote Desktop or Screen Sharing (VNC) when run as a daemon 
-// under OS 10.7.
+// Also, CGEventSourceSecondsSinceLastEventType() does not detect user activity 
+// when the user who launched the client is switched out by fast user switching.
 //
 // So we use weak-linking of NxIdleTime() to prevent a run-time crash from the 
 // dynamic linker and use it if it exists. 
-// If NXIdleTime does not exist, use CGEventSourceSecondsSinceLastEventType() 
-// under OS 10.7, or IOHIDGetParameter() under OS 10.6.
+// If NXIdleTime does not exist, we call both IOHIDGetParameter() and 
+// CGEventSourceSecondsSinceLastEventType().  If both return without error, 
+// we use the lower of the two returned values.
 //
 bool HOST_INFO::users_idle(
     bool check_all_logins, double idle_time_to_run, double *actual_idle_time
@@ -1606,6 +1614,7 @@ bool HOST_INFO::users_idle(
     static long     OSVersionInfo = 0;
     OSStatus        err = noErr;
     double          idleTime = 0;
+    double          idleTimeFromCG = 0;
     io_service_t    service;
     kern_return_t   kernResult = kIOReturnError; 
     UInt64          params;
@@ -1647,38 +1656,41 @@ bool HOST_INFO::users_idle(
             }
         }
     } else {        // NXIdleTime API does not exist in OS 10.6 and later
-    if ((OSVersionInfo >= 0x1070) && (! gstate.executing_as_daemon)) {
-                
-            idleTime =  CGEventSourceSecondsSinceLastEventType  
+        if (gEventHandle) {
+            kernResult = IOHIDGetParameter( gEventHandle, CFSTR(EVSIOIDLE), sizeof(UInt64), &params, &rcnt );
+            if ( kernResult != kIOReturnSuccess ) {
+                msg_printf(NULL, MSG_INFO,
+                    "User idle time measurement failed because IOHIDGetParameter failed."
+                );
+                error_posted = true;
+                goto bail;
+            }
+            idleTime = ((double)params) / 1000.0 / 1000.0 / 1000.0;
+            
+             if (!gstate.executing_as_daemon) {
+                idleTimeFromCG =  CGEventSourceSecondsSinceLastEventType  
                         (kCGEventSourceStateCombinedSessionState, kCGAnyInputEventType);
-    } else {        // OS Version < 10.7
-       if (gEventHandle) {
-                kernResult = IOHIDGetParameter( gEventHandle, CFSTR(EVSIOIDLE), sizeof(UInt64), &params, &rcnt );
-                if ( kernResult != kIOReturnSuccess ) {
-                    msg_printf(NULL, MSG_INFO,
-                        "User idle time measurement failed because IOHIDGetParameter failed."
+        
+                if (idleTimeFromCG < idleTime) {
+                    idleTime = idleTimeFromCG;
+                }
+            }
+        } else {
+            service = IOServiceGetMatchingService(kIOMasterPortDefault, IOServiceMatching(kIOHIDSystemClass));
+            if (service) {
+                 kernResult = IOServiceOpen(service, mach_task_self(), kIOHIDParamConnectType, &gEventHandle);
+            }
+            if ( (!service) || (kernResult != KERN_SUCCESS) ) {
+                // When the system first starts up, allow time for HIDSystem to be available if needed
+                if (TickCount() > (120*60)) {        // If system has been up for more than 2 minutes 
+                     msg_printf(NULL, MSG_INFO,
+                        "Could not connect to HIDSystem: user idle detection is disabled."
                     );
                     error_posted = true;
                     goto bail;
                 }
-                idleTime = ((double)params) / 1000.0 / 1000.0 / 1000.0;
-            } else {
-                service = IOServiceGetMatchingService(kIOMasterPortDefault, IOServiceMatching(kIOHIDSystemClass));
-                if (service) {
-                     kernResult = IOServiceOpen(service, mach_task_self(), kIOHIDParamConnectType, &gEventHandle);
-                }
-                if ( (!service) || (kernResult != KERN_SUCCESS) ) {
-                    // When the system first starts up, allow time for HIDSystem to be available if needed
-                    if (TickCount() > (120*60)) {        // If system has been up for more than 2 minutes 
-                         msg_printf(NULL, MSG_INFO,
-                            "Could not connect to HIDSystem: user idle detection is disabled."
-                        );
-                        error_posted = true;
-                        goto bail;
-                    }
-                }
-            }   // End (gEventHandle == NULL)
-        }       // End (OSVersionInfo < 0x1070)
+            }
+        }   // End (gEventHandle == NULL)
     }           // End NXIdleTime API does not exist
     
  bail:   
