@@ -542,6 +542,7 @@ void SCHEDULER_REPLY::clear() {
     message_ack = false;
     project_is_down = false;
     send_full_workload = false;
+    dont_use_dcf = false;
     send_time_stats_log = 0;
     send_job_log = 0;
     messages.clear();
@@ -872,6 +873,8 @@ int SCHEDULER_REPLY::parse(FILE* in, PROJECT* project) {
             continue;
         } else if (xp.parse_bool("send_full_workload", send_full_workload)) {
             continue;
+        } else if (xp.parse_bool("dont_use_dcf", dont_use_dcf)) {
+            continue;
         } else if (xp.parse_int("send_time_stats_log", send_time_stats_log)){
             continue;
         } else if (xp.parse_int("send_job_log", send_job_log)) {
