@@ -59,6 +59,7 @@ static void quit_client() {
 // Suspend client operations
 static void suspend_client() {
     gstate.os_requested_suspend = true;
+    gstate.os_requested_suspend_time = dtime();
 }
 
 // Resume client operations
@@ -139,6 +140,7 @@ static LRESULT CALLBACK WindowsMonitorSystemPowerWndProc(
 
                 // System is resuming from a normal power event
                 case PBT_APMRESUMESUSPEND:
+                    gstate.set_now();
                     msg_printf(NULL, MSG_INFO, "Windows is resuming operations");
 
                     // Check for a proxy
@@ -168,7 +170,7 @@ static DWORD WINAPI WindowsMonitorSystemPowerThread( LPVOID  ) {
     wc.hCursor       = NULL;
     wc.hbrBackground = NULL;
     wc.lpszMenuName  = NULL;
-	wc.lpszClassName = "BOINCWindowsMonitorSystemPower";
+    wc.lpszClassName = "BOINCWindowsMonitorSystemPower";
 
     if (!RegisterClass(&wc)) {
         log_message_error("Failed to register the WindowsMonitorSystem window class.");
@@ -177,7 +179,7 @@ static DWORD WINAPI WindowsMonitorSystemPowerThread( LPVOID  ) {
 
     g_hWndWindowsMonitorSystemPower = CreateWindow(
         wc.lpszClassName,
-		"BOINC Monitor System (Power)",
+        "BOINC Monitor System (Power)",
         WS_OVERLAPPEDWINDOW & ~WS_VISIBLE,
         CW_USEDEFAULT,
         CW_USEDEFAULT,
@@ -453,8 +455,7 @@ int initialize_service_dispatcher(int /*argc*/, char** /*argv*/) {
 //    the user defined main() routine to perform majority
 //    of the work.
 //
-void WINAPI BOINCServiceMain(DWORD /*dwArgc*/, LPTSTR * /*lpszArgv*/)
-{
+void WINAPI BOINCServiceMain(DWORD /*dwArgc*/, LPTSTR * /*lpszArgv*/) {
     // SERVICE_STATUS members that don't change in example
     //
     ssStatus.dwServiceType = SERVICE_WIN32_OWN_PROCESS;
@@ -480,11 +481,13 @@ cleanup:
 
     // try to report the stopped status to the service control manager.
     //
-    if (sshStatusHandle)
+    if (sshStatusHandle) {
         (VOID)ReportStatus(
             SERVICE_STOPPED,
             dwErr,
-            0);
+            0
+        );
+    }
 }
 
 
@@ -502,12 +505,10 @@ cleanup:
 //
 //  COMMENTS:
 //
-VOID WINAPI BOINCServiceCtrl(DWORD dwCtrlCode)
-{
+VOID WINAPI BOINCServiceCtrl(DWORD dwCtrlCode) {
     // Handle the requested control code.
     //
-    switch(dwCtrlCode)
-    {
+    switch(dwCtrlCode) {
         // Stop the service.
         //
         // SERVICE_STOP_PENDING should be reported before
@@ -516,14 +517,14 @@ VOID WINAPI BOINCServiceCtrl(DWORD dwCtrlCode)
         // which may result in a 1053 - The Service did not respond...
         // error.
         case SERVICE_CONTROL_STOP:
-		case SERVICE_CONTROL_SHUTDOWN:
+        case SERVICE_CONTROL_SHUTDOWN:
             ReportStatus(SERVICE_STOP_PENDING, ERROR_SUCCESS, 30000);
-			quit_client();
+            quit_client();
             return;
 
         // Pause the service.
         //
-		case SERVICE_CONTROL_PAUSE:
+        case SERVICE_CONTROL_PAUSE:
             ReportStatus(SERVICE_PAUSE_PENDING, ERROR_SUCCESS, 10000);
             suspend_client();
             ReportStatus(SERVICE_PAUSED, ERROR_SUCCESS, 10000);
@@ -531,13 +532,13 @@ VOID WINAPI BOINCServiceCtrl(DWORD dwCtrlCode)
 
         // Continue the service.
         //
-		case SERVICE_CONTROL_CONTINUE:
+        case SERVICE_CONTROL_CONTINUE:
             ReportStatus(SERVICE_CONTINUE_PENDING, ERROR_SUCCESS, 10000);
-			resume_client();
+            resume_client();
             ReportStatus(SERVICE_RUNNING, ERROR_SUCCESS, 10000);
             return;
 
-		// Update the service status.
+        // Update the service status.
         //
         case SERVICE_CONTROL_INTERROGATE:
             break;
@@ -570,10 +571,11 @@ VOID WINAPI BOINCServiceCtrl(DWORD dwCtrlCode)
 //
 //  COMMENTS:
 //
-BOOL ReportStatus(DWORD dwCurrentState,
-                  DWORD dwWin32ExitCode,
-                  DWORD dwWaitHint)
-{
+BOOL ReportStatus(
+    DWORD dwCurrentState,
+    DWORD dwWin32ExitCode,
+    DWORD dwWaitHint
+) {
     static DWORD dwCheckPoint = 1;
     BOOL fResult = TRUE;
 
@@ -587,15 +589,17 @@ BOOL ReportStatus(DWORD dwCurrentState,
     ssStatus.dwWaitHint = dwWaitHint;
 
     if ( ( dwCurrentState == SERVICE_RUNNING ) ||
-            ( dwCurrentState == SERVICE_STOPPED ) )
+            ( dwCurrentState == SERVICE_STOPPED )
+    ) {
         ssStatus.dwCheckPoint = 0;
-    else
+    } else {
         ssStatus.dwCheckPoint = dwCheckPoint++;
+    }
 
 
     // Report the status of the service to the service control manager.
     //
-	fResult = SetServiceStatus( sshStatusHandle, &ssStatus);
+    fResult = SetServiceStatus( sshStatusHandle, &ssStatus);
     if (!fResult) {
         LogEventErrorMessage(TEXT("SetServiceStatus"));
     }
@@ -617,8 +621,7 @@ BOOL ReportStatus(DWORD dwCurrentState,
 //
 //  COMMENTS:
 //
-VOID LogEventErrorMessage(LPTSTR lpszMsg)
-{
+VOID LogEventErrorMessage(LPTSTR lpszMsg) {
     TCHAR   szMsg[1024];
     HANDLE  hEventSource;
     LPTSTR  lpszStrings[2];
@@ -642,11 +645,12 @@ VOID LogEventErrorMessage(LPTSTR lpszMsg)
             2,                    // strings in lpszStrings
             0,                    // no bytes of raw data
             (LPCSTR*)lpszStrings, // array of error strings
-            NULL);                // no raw data
+            NULL                  // no raw data
+        );
 
         (VOID) DeregisterEventSource(hEventSource);
     }
- }
+}
 
 
 //
@@ -662,8 +666,7 @@ VOID LogEventErrorMessage(LPTSTR lpszMsg)
 //
 //  COMMENTS:
 //
-VOID LogEventWarningMessage(LPTSTR lpszMsg)
-{
+VOID LogEventWarningMessage(LPTSTR lpszMsg) {
     HANDLE  hEventSource;
     LPTSTR  lpszStrings[2];
 
@@ -703,8 +706,7 @@ VOID LogEventWarningMessage(LPTSTR lpszMsg)
 //
 //  COMMENTS:
 //
-VOID LogEventInfoMessage(LPTSTR lpszMsg)
-{
+VOID LogEventInfoMessage(LPTSTR lpszMsg) {
     HANDLE  hEventSource;
     LPTSTR  lpszStrings[2];
 
