@@ -37,7 +37,9 @@ DB_CONN::DB_CONN() {
     mysql = 0;
 }
 
-int DB_CONN::open(char* db_name, char* db_host, char* db_user, char* dbpassword) {
+int DB_CONN::open(
+    char* db_name, char* db_host, char* db_user, char* dbpassword
+) {
     mysql = mysql_init(0);
     if (!mysql) return ERR_DB_CANT_INIT;
 
@@ -68,11 +70,23 @@ int DB_CONN::open(char* db_name, char* db_host, char* db_user, char* dbpassword)
         my_bool mbReconnect = 1;
         mysql_options(mysql, MYSQL_OPT_RECONNECT, &mbReconnect);
     }
+
+    // parse hostname:port
+    //
+    char host[256];
+    int port = 0;
+    strcpy(host, db_host);
+    char* p = strchr(host, ':');
+    if (p) {
+        *p = 0;
+        port = atoi(p+1);
+    }
+
     // CLIENT_FOUND_ROWS means that the # of affected rows for an update
     // is the # matched by the where, rather than the # actually changed
     //
     mysql = mysql_real_connect(
-        mysql, db_host, db_user, dbpassword, db_name, 0, 0, CLIENT_FOUND_ROWS
+        mysql, host, db_user, dbpassword, db_name, port, 0, CLIENT_FOUND_ROWS
     );
     if (mysql == 0) return ERR_DB_CANT_CONNECT;
 
@@ -250,12 +264,17 @@ int DB_BASE::update_field(const char* clause, const char* where_clause) {
 // delete record
 //
 int DB_BASE::delete_from_db() {
-    char vals[MAX_QUERY_LEN], query[MAX_QUERY_LEN];
-    db_print(vals);
+    char query[MAX_QUERY_LEN];
     sprintf(query, "delete from %s where id=%u", table_name, get_id());
     return db->do_query(query);
 }
 
+int DB_BASE::delete_from_db_multi(const char* where_clause) {
+    char query[MAX_QUERY_LEN];
+    sprintf(query, "delete from %s where %s", table_name, where_clause);
+    return db->do_query(query);
+}
+
 int DB_BASE::get_field_ints(const char* fields, int nfields, int* vals) {
     char query[MAX_QUERY_LEN];
     int retval;
@@ -506,4 +525,4 @@ void escape_mysql_like_pattern(const char* in, char* out) {
     }
 }
 
-const char *BOINC_RCSID_43d919556b = "$Id: db_base.cpp 24555 2011-11-09 07:41:49Z davea $";
+const char *BOINC_RCSID_43d919556b = "$Id: db_base.cpp 25405 2012-03-12 21:45:29Z davea $";
