@@ -28,35 +28,36 @@ page_head(tra("Forum search"));
 
 start_table();
 echo "<form action=\"forum_search_action.php\" method=\"post\">";
-row1("Search query");
-row2("Search for keywords:<br />
-    <span class=\"smalltext\">Posts that contain all the specified words will be displayed</span>",
-    '<input type="text" style="width: 290px" name="search_keywords" size="30" /><br />
-    <span class="smalltext">For example: "screensaver freeze"</span>');
-row2("Search for author ID:<br />
-    <span class=\"smalltext\">Only posts by this author will be displayed</span>",
-    '<input type="text" style="width: 150px" name="search_author" size="10" /><br />
-    <span class="smalltext">For example: "43214"</span>');
+row1(tra("Search query"));
+row2(tra("Search for keywords:")."<br />
+    <span class=\"smalltext\">".tra("Posts that contain all the specified words will be displayed")."</span>",
+    "<input type=\"text\" style=\"width: 290px\" name=\"search_keywords\" size=\"30\" /><br />
+    <span class=\"smalltext\">".tra("For example: \"screensaver freeze\"")."</span>");
+row2(tra("Search for author ID:")."<br />
+    <span class=\"smalltext\">".tra("Only posts by this author will be displayed")."</span>",
+    "<input type=\"text\" style=\"width: 150px\" name=\"search_author\" size=\"10\" /><br />
+    <span class=\"smalltext\">".tra("For example: \"43214\"")."</span>");
 
-row1("Search options");
-row2("Search limits<br />
-    <span class=\"smalltext\">Search at most this many days back in time</span>",
-    '<select name="search_max_time">
-    <option value="1">1 day</option>
-    <option value="3">3 days</option>
-    <option value="7">7 days</option>
-    <option value="15">15 days</option>
-    <option value="30" selected>30 days</option>
-    <option value="90">3 months</option>
-    <option value="180">6 months</option>
-    <option value="360">1 year</option>
-    </select>');
+row1(tra("Search options"));
+row2(tra("Search limits")."<br />
+    <span class=\"smalltext\">".tra("Search at most this many days back in time")."</span>",
+    "<select name=\"search_max_time\">
+    <option value=\"1\">".tra("1 day")."</option>
+    <option value=\"3\">".tra("%1 days", "3")."</option>
+    <option value=\"7\">".tra("%1 days", "7")."</option>
+    <option value=\"15\">".tra("%1 days", "15")."</option>
+    <option value=\"30\" selected>".tra("%1 days", "30")."</option>
+    <option value=\"90\">".tra("%1 months", "3")."</option>
+    <option value=\"180\">".tra("%1 months", "6")."</option>
+    <option value=\"365\">".tra("1 year")."</option>
+    <option value=\"0\">".tra("no limit")."</option>
+    </select>");
 
 $forumid = null;
 if (get_str("forumid",true)){
     $forumid = get_str("forumid");
 }
-$forumlist="<option value=\"-1\">All</option>";
+$forumlist="<option value=\"-1\">".tra("All")."</option>";
 $categories = BoincCategory::enum();
 foreach ($categories as $category) {
     $forums = BoincForum::enum("parent_type=0 and category=$category->id");
@@ -68,8 +69,8 @@ foreach ($categories as $category) {
         }
     }
 }
-row2("Forum<br />
-    <span class=\"smalltext\">Only display posts from this forum</span>",
+row2(tra("Forum")."<br />
+    <span class=\"smalltext\">".tra("Only display posts from this forum")."</span>",
     '<select name="search_forum">'.$forumlist.'</select');
 
 $sortlist = null;
@@ -80,16 +81,15 @@ foreach ($thread_sort_styles as $id => $style){
         $sortlist.="<option value=\"".$id."\">".$style."</option>";
     }
 }
-row2("Sort by", 
+row2(tra("Sort by"), 
     '<select name="search_sort">'.$sortlist.'</select');
 
 row1("&nbsp;");
-row2("","<input type=\"submit\" value=\"Start the search\">");
+row2("","<input type=\"submit\" value=\"".tra("Start the search")."\">");
 echo "</form>";
 end_table();
 
 page_tail();
-exit;
 
-$cvs_version_tracker[]="\$Id: forum_search.php 23010 2011-02-09 22:11:34Z davea $";  //Generated automatically - do not edit
+$cvs_version_tracker[]="\$Id: forum_search.php 24129 2011-09-06 04:34:29Z davea $";  //Generated automatically - do not edit
 ?>
