@@ -16,8 +16,6 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 
-
-
 // Change the status of a thread.
 // A thread can be either unsolved or solved (used in the Q&A part)
 
@@ -43,13 +41,13 @@ if ($logged_in_user->id == $owner->id){
         error_page("Could not update the status of the thread: ".$thread->id);
     }
 } else {
-    error_page("You must be the creator of the thread to update its status");
+    error_page("You must be the creator of the thread to update its status.");
 }
 
 // --------------
 
-page_head("Thread status updated");
-echo "<p>The status has been updated.</p>";
-echo "<p><a href=\"forum_thread.php?nowrap=true&id=".$thread->id."\">Return to the thread</a></p>";
+page_head(tra("Thread status updated"));
+echo "<p>".tra("The status has been updated.")."</p>";
+echo "<p><a href=\"forum_thread.php?nowrap=true&id=".$thread->id."\">".tra("Return to thread")."</a></p>";
 page_tail();
 ?>
