@@ -33,6 +33,9 @@
 
 
 #include "edf_sim.h"
+#ifdef SIM
+extern FILE* logfile;
+#endif
 
 using std::vector;
 
@@ -43,6 +46,9 @@ using std::vector;
 #define DETAIL   2
     // show every step of simulation
 
+#define TIME_SCALE 1
+//#define TIME_SCALE 3600
+
 static void log_msg(int level, const char* format, ...) {
 #ifdef SIM
 #else
@@ -61,7 +67,7 @@ static void log_msg(int level, const char* format, ...) {
     va_list va;
     va_start(va, format);
 #ifdef SIM
-    vfprintf(stderr, format, va);
+    vfprintf(logfile, format, va);
 #else
     log_messages.vprintf(MSG_NORMAL, format, va);
 #endif
@@ -108,23 +114,23 @@ void mark_edf_misses (int ncpus, vector<IP_RESULT>& ip_results){
                 lowest_booked_cpu = j;
             }
         }
-      
+
         booked_to[lowest_booked_cpu] += r.cpu_time_remaining;
         log_msg(DETAIL, "[edf_detail]   running %s on cpu %d; finishes at %.2f\n",
-            r.name, lowest_booked_cpu, booked_to[lowest_booked_cpu]/3600
+            r.name, lowest_booked_cpu, booked_to[lowest_booked_cpu]/TIME_SCALE
         );
         if (booked_to[lowest_booked_cpu] > r.computation_deadline) {
-	        r.misses_deadline = true;
-	        r.estimated_completion_time = booked_to[lowest_booked_cpu];
-	        log_msg(DETAIL, "[edf_detail]   %s misses_deadline; est completion %.2f\n",
-                r.name, booked_to[lowest_booked_cpu]/3600
+            r.misses_deadline = true;
+            r.estimated_completion_time = booked_to[lowest_booked_cpu];
+            log_msg(DETAIL, "[edf_detail]   %s misses_deadline; est completion %.2f\n",
+                r.name, booked_to[lowest_booked_cpu]/TIME_SCALE
             );
         } else {
-	        r.misses_deadline = false;
-	        log_msg(DETAIL, "[edf_detail]   %s makes deadline; est completion %.2f\n",
-                r.name, booked_to[lowest_booked_cpu]/3600
+            r.misses_deadline = false;
+            log_msg(DETAIL, "[edf_detail]   %s makes deadline; est completion %.2f\n",
+                r.name, booked_to[lowest_booked_cpu]/TIME_SCALE
             );
-	        // if result doesn't miss its deadline,
+            // if result doesn't miss its deadline,
             // then the estimated_completion_time is of no use
         }
     }
@@ -142,13 +148,13 @@ void init_ip_results(
 
     log_msg(DETAIL,
         "[edf_detail] init_ip_results; work_buf_min %.2f ncpus %d:\n",
-        work_buf_min/3600, ncpus
+        work_buf_min/TIME_SCALE, ncpus
     );
     for (i=0; i<ip_results.size(); i++) {
         IP_RESULT& r = ip_results[i];
         r.computation_deadline = r.report_deadline - work_buf_min;
         log_msg(DETAIL, "[edf_detail]     %s: deadline %.2f cpu %.2f\n",
-            r.name, r.computation_deadline/3600, r.cpu_time_remaining/3600
+            r.name, r.computation_deadline/TIME_SCALE, r.cpu_time_remaining/TIME_SCALE
         );
     }
 
@@ -158,24 +164,24 @@ void init_ip_results(
 }
 
 #if 0
-// Sort test_results by computation_deadline. 
+// Sort test_results by computation_deadline.
 // For each test result in ascending order of deadline,
 // see whether adding it to the work queue would cause deadline misses
 // or deadline miss delays.
 // If a test result passes these checks, append it to the work queue
 // for further result additions.
-// Return list of new results that can be sent to the client.  
+// Return list of new results that can be sent to the client.
 //
 // NOTE: should we sort by increasing deadline or by increasing slack time?
 //
 vector<TEMP_RESULT> REQUEST_HANDLER_WORK_SEND::find_sendable_test_results (
     vector<TEMP_RESULT> test_results,
-    int ncpus, 
-    vector<TEMP_RESULT> ipp_results, 
+    int ncpus,
+    vector<TEMP_RESULT> ipp_results,
     double cpu_pessimism_factor // = 1 by default
 ) {
     //test results to send
-    vector<TEMP_RESULT> sendable_test_results; 
+    vector<TEMP_RESULT> sendable_test_results;
     vector<TEMP_RESULT>::iterator test_results_it;
 
     sort(test_results.begin(), test_results.end(), lessthan_deadline);
@@ -214,15 +220,15 @@ vector<TEMP_RESULT> REQUEST_HANDLER_WORK_SEND::find_sendable_test_results (
 //
 bool check_candidate (
     IP_RESULT& candidate,
-    int ncpus, 
+    int ncpus,
     vector<IP_RESULT> ip_results        // passed by value (copy)
 ) {
     double booked_to[128];     // keeps track of when each cpu is free
     int j;
 
     log_msg(DETAIL, "[edf_detail] check_candidate %s: dl %.2f cpu %.2f\n",
-        candidate.name, candidate.computation_deadline/3600,
-        candidate.cpu_time_remaining/3600
+        candidate.name, candidate.computation_deadline/TIME_SCALE,
+        candidate.cpu_time_remaining/TIME_SCALE
     );
 
     for (j=0; j<ncpus; j++) {
@@ -244,14 +250,14 @@ bool check_candidate (
         double lowest_booked_time = booked_to[0];
         int lowest_booked_cpu = 0;
         for (j=1; j<ncpus; j++) {
-	        if (booked_to[j] < lowest_booked_time) {
+            if (booked_to[j] < lowest_booked_time) {
                 lowest_booked_time = booked_to[j];
                 lowest_booked_cpu = j;
             }
         }
         booked_to[lowest_booked_cpu] += r.cpu_time_remaining;
-        log_msg(DETAIL, "[edf_detail]   running %s on cpu %d; finishes at %.2f\n",
-            r.name, lowest_booked_cpu, booked_to[lowest_booked_cpu]/3600
+        log_msg(DETAIL, "[edf_detail]   running %s on cpu %d; deadline %f, finishes at %.2f\n",
+            r.name, lowest_booked_cpu, r.computation_deadline, booked_to[lowest_booked_cpu]/TIME_SCALE
         );
 
         // return false if completion time if > computation_deadline AND
@@ -260,17 +266,17 @@ bool check_candidate (
         if (booked_to[lowest_booked_cpu] > r.computation_deadline
             && !r.misses_deadline
         ) {
-	        log_msg(SUMMARY,
+            log_msg(SUMMARY,
                 "[send]  cand. fails; %s now misses deadline: %.2f > %.2f\n",
-                r.name, booked_to[lowest_booked_cpu]/3600,
-                r.computation_deadline/3600
+                r.name, booked_to[lowest_booked_cpu]/TIME_SCALE,
+                r.computation_deadline/TIME_SCALE
             );
             return false;
         }
         // check a late result (i.e., one that would have missed its
         // deadline) // would be made even later
         //
-        if (r.misses_deadline 
+        if (r.misses_deadline
             && booked_to[lowest_booked_cpu] > r.estimated_completion_time
         ){
             log_msg(SUMMARY,
