@@ -39,7 +39,7 @@
 // It maintains a DB enumerator (DB_WORK_ITEM).
 // scan_work_array() scans the work array.
 // looking for empty slots and trying to fill them in.
-// The  enumeration may return results already in the array.
+// The enumeration may return results already in the array.
 // So, for each result, we scan the entire array to make sure
 // it's not there already (can this be streamlined?)
 //
@@ -55,7 +55,7 @@
 //   stop the scan and sleep for N seconds
 // - Otherwise immediately start another scan
 
-// If -allapps is used:
+// If --allapps is used:
 // - there are separate DB enumerators for each app
 // - the work array is interleaved by application, based on their weights.
 //   slot_to_app[] maps slot (i.e. work array index) to app index.
@@ -71,7 +71,7 @@
 // (proportional to the total RAC of hosts in that class).
 // This is to maximize the likelihood of having work for an average host.
 //
-// If you use different HR types between apps, you must use -allapps.
+// If you use different HR types between apps, you must use --allapps.
 // Otherwise we wouldn't know how many slots to reserve for each HR type.
 //
 // It's OK to use HR for some apps and not others.
@@ -142,7 +142,7 @@ int purge_stale_time = 0;
 int num_work_items = MAX_WU_RESULTS;
 int enum_limit = MAX_WU_RESULTS*2;
 
-// The following defined if -allapps:
+// The following defined if --allapps:
 int *enum_sizes;
     // the enum size per app; else not used
 int *app_indices;
@@ -232,7 +232,7 @@ void hr_count_slots() {
 // 
 static bool get_job_from_db(
     DB_WORK_ITEM& wi,    // enumerator to get job from
-    int app_index,       // if using -allapps, the app index
+    int app_index,       // if using --allapps, the app index
     int& enum_phase,
     int& ncollisions
 ) {
@@ -252,7 +252,7 @@ static bool get_job_from_db(
     int hrt = ssp->apps[app_index].homogeneous_redundancy;
 
     while (1) {
-        if (hrt) {
+        if (hrt && config.hr_allocate_slots) {
             retval = wi.enumerate_all(enum_size, select_clause);
         } else {
             retval = wi.enumerate(enum_size, select_clause, order_clause);
@@ -326,7 +326,7 @@ static bool get_job_from_db(
 
             // if using HR, check whether we've exceeded quota for this class
             //
-            if (hrt) {
+            if (hrt && config.hr_allocate_slots) {
                 if (!hr_info.accept(hrt, wi.wu.hr_class)) {
                     log_messages.printf(MSG_DEBUG,
                         "rejecting [RESULT#%u] because HR class %d/%d over quota\n",
@@ -341,7 +341,7 @@ static bool get_job_from_db(
     return false;   // never reached
 }
 
-// This function decides the interleaving used for -allapps.
+// This function decides the interleaving used for --allapps.
 // Inputs:
 //   n (number of weights)
 //   k (length of vector)
@@ -420,7 +420,7 @@ static bool scan_work_array(vector<DB_WORK_ITEM> &work_items) {
         }
     }
 
-    if (using_hr) {
+    if (using_hr && config.hr_allocate_slots) {
         hr_count_slots();
     }
 
@@ -607,7 +607,7 @@ void hr_init() {
         if (some_app_uses_hr) {
             if (apps_differ && !all_apps) {
                 log_messages.printf(MSG_CRITICAL,
-                    "You must use -allapps if apps have different HR\n"
+                    "You must use --allapps if apps have different HR\n"
                 );
                 exit(1);
             }
@@ -616,34 +616,38 @@ void hr_init() {
         }
     }
     using_hr = true;
-    hr_info.init();
-    retval = hr_info.read_file();
-    if (retval) {
-        log_messages.printf(MSG_CRITICAL,
-            "Can't read HR info file: %s\n", boincerror(retval)
-        );
-        exit(1);
-    }
+    if (config.hr_allocate_slots) {
+        hr_info.init();
+        retval = hr_info.read_file();
+        if (retval) {
+            log_messages.printf(MSG_CRITICAL,
+                "Can't read HR info file: %s\n", boincerror(retval)
+            );
+            exit(1);
+        }
 
-    // find the weight for each HR type
-    //
-    for (i=0; i<ssp->napps; i++) {
-        hrt = ssp->apps[i].homogeneous_redundancy;
-        hr_info.type_weights[hrt] += ssp->apps[i].weight;
-        hr_info.type_being_used[hrt] = true;
-    }
+        // find the weight for each HR type
+        //
+        for (i=0; i<ssp->napps; i++) {
+            hrt = ssp->apps[i].homogeneous_redundancy;
+            hr_info.type_weights[hrt] += ssp->apps[i].weight;
+            hr_info.type_being_used[hrt] = true;
+        }
 
-    // compute the slot allocations for HR classes
-    //
-    hr_info.allocate(ssp->max_wu_results);
-    hr_info.show(stderr);
+        // compute the slot allocations for HR classes
+        //
+        hr_info.allocate(ssp->max_wu_results);
+        hr_info.show(stderr);
+    }
 }
 
 // write a summary of feeder state to stderr
 //
 void show_state(int) {
     ssp->show(stderr);
-    hr_info.show(stderr);
+    if (config.hr_allocate_slots) {
+        hr_info.show(stderr);
+    }
 }
 
 void show_version() {
@@ -871,4 +875,4 @@ int main(int argc, char** argv) {
     feeder_loop();
 }
 
-const char *BOINC_RCSID_57c87aa242 = "$Id: feeder.cpp 25114 2012-01-20 23:48:07Z davea $";
+const char *BOINC_RCSID_57c87aa242 = "$Id: feeder.cpp 25435 2012-03-16 17:23:55Z romw $";
