@@ -334,23 +334,16 @@ int create_work(
 
 // STUFF RELATED TO FILE UPLOAD/DOWNLOAD
 
-int get_file(
-    int host_id, const char* file_name, vector<const char*> urls,
+int get_file_xml(
+    const char* file_name, vector<const char*> urls,
     double max_nbytes,
     double report_deadline,
     bool generate_upload_certificate,
-    R_RSA_PRIVATE_KEY& key
-) {;
+    R_RSA_PRIVATE_KEY& key,
+    char* out
+) {
     char buf[8192];
-    DB_MSG_TO_HOST mth;
-    int retval;
-
-    mth.clear();
-    mth.create_time = time(0);
-    mth.hostid = host_id;
-    strcpy(mth.variety, "file_xfer");
-    mth.handled = false;
-    sprintf(mth.xml,
+    sprintf(out,
         "<app>\n"
         "    <name>file_xfer</name>\n"
         "</app>\n"
@@ -366,7 +359,7 @@ int get_file(
     );
     for (unsigned int i=0; i<urls.size(); i++) {
         sprintf(buf, "    <url>%s</url>\n", urls[i]);
-        strcat(mth.xml, buf);
+        strcat(out, buf);
     }
     sprintf(buf,
         "</file_info>\n"
@@ -388,11 +381,33 @@ int get_file(
         file_name,
         report_deadline
     );
-    strcat(mth.xml, buf);
+    strcat(out, buf);
     if (generate_upload_certificate) {
-        add_signatures(mth.xml, key);
+        add_signatures(out, key);
     }
+    return 0;
+}
 
+int create_get_file_msg(
+    int host_id, const char* file_name, vector<const char*> urls,
+    double max_nbytes,
+    double report_deadline,
+    bool generate_upload_certificate,
+    R_RSA_PRIVATE_KEY& key
+) {
+    DB_MSG_TO_HOST mth;
+    int retval;
+
+    mth.clear();
+    mth.create_time = time(0);
+    mth.hostid = host_id;
+    strcpy(mth.variety, "file_xfer");
+    mth.handled = false;
+    get_file_xml(
+        file_name, urls, max_nbytes, report_deadline,
+        generate_upload_certificate, key,
+        mth.xml
+    );
     retval = mth.insert();
     if (retval) {
         fprintf(stderr, "msg_to_host.insert(): %s\n", boincerror(retval));
@@ -401,20 +416,14 @@ int get_file(
     return 0;
 }
 
-int put_file(
-    int host_id, const char* file_name,
+int put_file_xml(
+    const char* file_name,
     vector<const char*> urls, const char* md5, double nbytes,
-    double report_deadline
+    double report_deadline,
+    char* out
 ) {
     char buf[8192];
-    DB_MSG_TO_HOST mth;
-    int retval;
-    mth.clear();
-    mth.create_time = time(0);
-    mth.hostid = host_id;
-    strcpy(mth.variety, "file_xfer");
-    mth.handled = false;
-    sprintf(mth.xml,
+    sprintf(out,
         "<app>\n"
         "    <name>file_xfer</name>\n"
         "</app>\n"
@@ -428,7 +437,7 @@ int put_file(
     );
     for (unsigned int i=0; i<urls.size(); i++) {
         sprintf(buf, "    <url>%s</url>\n", urls[i]);
-        strcat(mth.xml, buf);
+        strcat(out, buf);
     }
     sprintf(buf,
         "    <md5_cksum>%s</md5_cksum>\n"
@@ -455,7 +464,45 @@ int put_file(
         file_name,
         report_deadline
     );
-    strcat(mth.xml, buf);
+    strcat(out, buf);
+    return 0;
+}
+
+int create_put_file_msg(
+    int host_id, const char* file_name,
+    vector<const char*> urls, const char* md5, double nbytes,
+    double report_deadline
+) {
+    DB_MSG_TO_HOST mth;
+    int retval;
+    mth.clear();
+    mth.create_time = time(0);
+    mth.hostid = host_id;
+    strcpy(mth.variety, "file_xfer");
+    mth.handled = false;
+    put_file_xml(file_name, urls, md5, nbytes, report_deadline, mth.xml);
+    retval = mth.insert();
+    if (retval) {
+        fprintf(stderr, "msg_to_host.insert(): %s\n", boincerror(retval));
+        return retval;
+    }
+    return 0;
+}
+
+int delete_file_xml(const char* file_name, char* out) {
+    sprintf(out, "<delete_file_info>%s</delete_file_info>\n", file_name);
+    return 0;
+}
+
+int create_delete_file_msg(int host_id, const char* file_name) {
+    DB_MSG_TO_HOST mth;
+    int retval;
+    mth.clear();
+    mth.create_time = time(0);
+    mth.hostid = host_id;
+    mth.handled = false;
+    delete_file_xml(file_name, mth.xml);
+    sprintf(mth.variety, "delete_file");
     retval = mth.insert();
     if (retval) {
         fprintf(stderr, "msg_to_host.insert(): %s\n", boincerror(retval));
@@ -488,4 +535,4 @@ int cancel_jobs(int min_id, int max_id) {
     return 0;
 }
 
-const char *BOINC_RCSID_b5f8b10eb5 = "$Id: backend_lib.cpp 25169 2012-01-30 22:39:13Z davea $";
+const char *BOINC_RCSID_b5f8b10eb5 = "$Id: backend_lib.cpp 25341 2012-02-24 22:55:11Z davea $";
